==> haskell-attoparsec-0.13.2.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
key: attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
abi: 8e6e77bd73af6a8072fdc40742d8861e
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    transformers-0.5.5.0 text-1.2.3.0
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.2.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
key: attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
abi: 07053c5359c7530f0cb8534ff020b021
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    transformers-0.5.5.0 text-1.2.3.0
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
